@@ -1,3 +1,23 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * Copyright (C) 2002-2004 Edd Dumbill <edd@usefulinc.com>
+ * Copyright (C) 2005-2007 Bastien Nocera <hadess@hadess.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ */
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -25,7 +45,11 @@ about_activated(GtkMenuItem *item, gpointer data)
 			   "copyright", "Copyright \xc2\xa9 2003-2004 Edd Dumbill\nCopyright \xc2\xa9 2005-2007 Bastien Nocera",
 			   "documenters", documenters,
 			   "logo-icon-name", "phone",
+#if GTK_CHECK_VERSION (2, 11, 0)
 			   "program-name", _("Phone Manager"),
+#else
+			   "name", _("Phone Manager"),
+#endif /* GTK+ 2.11.0 */
 			   "version", VERSION,
 			   "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ?  translator_credits : NULL,
 			   "website", "http://live.gnome.org/PhoneManager",
